==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.server/src/com/openexchange/groupware/reminder/ReminderPool.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */



package com.openexchange.groupware.reminder;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import org.apache.commons.logging.Log;
import com.openexchange.log.LogFactory;
import com.openexchange.server.services.ServerServiceRegistry;
import com.openexchange.timer.TimerService;

/**
 * ReminderPool - Not used by now.
 *
 * @author <a href="mailto:sebastian.kauss@open-xchange.org">Sebastian Kauss</a>
 */
public class ReminderPool implements Runnable {

	private static final Map<String, ReminderEvent> register = new HashMap<String, ReminderEvent>();

	private static final Set<ReminderObject> pool = new HashSet<ReminderObject>();

	private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ReminderPool.class));

	public ReminderPool(final ReminderConfig reminderConfig) {
		if (reminderConfig.isReminderEnabled()) {
			if (LOG.isInfoEnabled()) {
				LOG.info("Starting ReminderPool");
			}

			//addReminderEvent(new ProjectsReminderEvent(), Types.PROJECT);

			final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class);
            if (timer != null) {
                timer.schedule(this, reminderConfig.getReminderInterval());
            }
		} else {
			if (LOG.isInfoEnabled()) {
				LOG.info("ReminderPool is disabled");
			}
		}
	}

	@Override
    public void run() {
	    // TODO: Do something useful here
	}

	public static void addReminderEvent( final ReminderEvent reminderevent, final int module ) {
		register.put(String.valueOf(module), reminderevent);
	}

	public static void add( final ReminderObject reminderobject ) {
		pool.add(reminderobject);
	}

	public static void remove( final ReminderObject reminderobject ) {
		pool.remove(reminderobject);
	}
}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/groupware/reminder/ReminderPool.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */



package com.openexchange.groupware.reminder;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import com.openexchange.server.services.ServerServiceRegistry;
import com.openexchange.timer.TimerService;

/**
 * ReminderPool - Not used by now.
 *
 * @author <a href="mailto:sebastian.kauss@open-xchange.org">Sebastian Kauss</a>
 */
public class ReminderPool implements Runnable {

	private static final Map<String, ReminderEvent> register = new HashMap<String, ReminderEvent>();

	private static final Set<ReminderObject> pool = new HashSet<ReminderObject>();

	private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ReminderPool.class);

	public ReminderPool(final ReminderConfig reminderConfig) {
		if (reminderConfig.isReminderEnabled()) {
			LOG.info("Starting ReminderPool");

			//addReminderEvent(new ProjectsReminderEvent(), Types.PROJECT);

			final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class);
            if (timer != null) {
                timer.schedule(this, reminderConfig.getReminderInterval());
            }
		} else {
			LOG.info("ReminderPool is disabled");
		}
	}

	@Override
    public void run() {
	    // TODO: Do something useful here
	}

	public static void addReminderEvent( final ReminderEvent reminderevent, final int module ) {
		register.put(String.valueOf(module), reminderevent);
	}

	public static void add( final ReminderObject reminderobject ) {
		pool.add(reminderobject);
	}

	public static void remove( final ReminderObject reminderobject ) {
		pool.remove(reminderobject);
	}
}
